==> nextcloud-app-tasks-0.13.6-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/vi.js <==
OC.L10N.register(
    "tasks",
    {
    "Important" : "Quan trọng",
    "Today" : "Hôm nay",
    "Week" : "Tuần",
    "All" : "Tất cả",
    "Current" : "Hiện tại",
    "Completed" : "Hoàn thành",
    "Tasks" : "Nhiệm vụ",
    "The Tasks app for Nextcloud" : "Ứng dụng Nhiệm vụ cho Nextcloud",
    "Once enabled, a new Tasks menu will appear in your Nextcloud apps menu. From there you can add and delete tasks, edit their title, description, start and due dates and mark them as important. Tasks can be shared between users. Tasks can be synchronized using CalDav (each task list is linked to an Nextcloud calendar, to sync it to your local client - Thunderbird, Evolution, KDE Kontact, iCal, … - just add the calendar as a remote calendar in your client). You can download your tasks as ICS files using the download button for each calendar." : "Một khi được kích hoạt, một bảng chọn Nhiệm vụ mới sẽ xuất hiện trong bảng chọn ứng dụng trong Nextcloud của bạn. Từ đó bạn có thể thêm vào và xóa các nhiệm vụ, sửa đổi các tiêu đề, mô tả, các ngày bắt đầu và ngày đến hạn và gắn dấu quan trọng cho chúng. Nhiệm vụ có thể được chia sẻ giữa các người dùng. Nhiệm vụ có thể được đồng bộ bằng cách sử dụng qua CalDAV (mỗi danh sách nhiệm vụ được liên kết với một lịch Nextcloud, để đồng bộ nó vào máy khách cục bộ ). Bạn có thể tải xuống các nhiệm vụ của bạn dưới dạng tệp ICS bằng cách sử dụng nút tải xuống cho mỗi lịch.",
    "Add List…" : "Thêm vào danh sách…",
    "New List" : "Danh sách mới",
    "Cancel" : "Hủy",
    "Save" : "Lưu",
    "The name \"{calendar}\" is already used." : "Tên \"{calendar}\" đã được sử dụng.",
    "An empty name is not allowed." : "Để trống tên không được cho phép.",
    "Share with users or groups" : "Chia sẽ với người dùng hoặc nhóm",
    "No users or groups" : "Không có người dùng hay nhóm",
    "can edit" : "Có thể chỉnh sửa",
    "Unshare with {displayName}" : "Gỡ chia sẻ với {displayName}",
    "Unable to delete the share." : "Không thể xóa chia sẻ.",
    "Unable to change permissions." : "Không thể thay đổi quyền hạn.",
    "Edit" : "Sửa",
    "Copy private link" : "Sao chép liên kết riêng tư",
    "Copied" : "Đã sao chép",
    "Can not copy" : "Không thể sao chép",
    "Download" : "Tải về",
    "Delete" : "Xóa",
    "Unshare" : "Bỏ chia sẽ",
    "Calendar link copied to clipboard." : "Liên kết của lịch đã được sao chép vào bảng tạm.",
    "Calendar link could not be copied to clipboard." : "liên kết của lịch không thể sao chép vào bảng tạm.",
    "An error occurred, unable to delete the calendar." : "Một lỗi đã xảy ra, không thể xóa lịch.",
    "Hidden" : "Ẩn",
    "Automatic" : "Tự động",
    "No errors" : "Không có lỗi",
    "Open your browser console for more details" : "Mở trong trình duyệt để biết thêm chi tiết",
    "Due date" : "Thời hạn",
    "Last modified" : "Lần cuối chỉnh sửa",
    "All day" : "Cả ngày",
    "Add this as a new category" : "Thêm mục này như là mục mới",
    "When shared show full event" : "Khi được chia sẻ thì thể hiện đầy đủ sự kiện",
    "When shared show only busy" : "Khi được chia sẻ thì chỉ thể hiện đang bận",
    "When shared hide this event" : "Khi được chia sẻ thì ẩn sự kiện này đi",
    "An error occurred" : "Có lỗi đã xảy ra"
},
"nplurals=1; plural=0;");

==> nextcloud-app-tasks-0.14.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/vi.js <==
OC.L10N.register(
    "tasks",
    {
    "Important" : "Quan trọng",
    "Today" : "Hôm nay",
    "Week" : "Tuần",
    "All" : "Tất cả",
    "Current" : "Hiện tại",
    "Completed" : "Hoàn thành",
    "Tasks" : "Nhiệm vụ",
    "The Tasks app for Nextcloud" : "Ứng dụng Nhiệm vụ cho Nextcloud",
    "Hidden" : "Ẩn",
    "Automatic" : "Tự động",
    "Share with users or groups" : "Chia sẽ với người dùng hoặc nhóm",
    "No users or groups" : "Không có người dùng hay nhóm",
    "Can edit" : "Có thể chỉnh sửa",
    "Unshare with {displayName}" : "Gỡ chia sẻ với {displayName}",
    "Unable to delete the share." : "Không thể xóa chia sẻ.",
    "Unable to change permissions." : "Không thể thay đổi quyền hạn.",
    "Edit" : "Sửa",
    "Copy private link" : "Sao chép liên kết riêng tư",
    "Copied" : "Đã sao chép",
    "Export" : "Xuất ra",
    "Delete" : "Xóa",
    "Unshare" : "Bỏ chia sẽ",
    "Save" : "Lưu",
    "Calendar link copied to clipboard." : "Liên kết của lịch đã được sao chép vào bảng tạm.",
    "Calendar link could not be copied to clipboard." : "liên kết của lịch không thể sao chép vào bảng tạm.",
    "The name \"{calendar}\" is already used." : "Tên \"{calendar}\" đã được sử dụng.",
    "An empty name is not allowed." : "Để trống tên không được cho phép.",
    "An error occurred, unable to delete the calendar." : "Một lỗi đã xảy ra, không thể xóa lịch.",
    "Trash bin" : "Thùng rác",
    "Name" : "Tên",
    "Deleted" : "Đã xoá",
    "Restore" : "Khôi phục",
    "Delete permanently" : "Xoá vĩnh viễn",
    "Empty trash bin" : "Dọn thùng rác",
    "Untitled task" : "Nhiệm vụ không tiêu đề",
    "Untitled event" : "Sự kiện không tiêu đề",
    "Unknown calendar" : "Lịch không rõ nguồn",
    "Could not load deleted calendars and objects" : "Không thể hiển thị lịch hoặc các đối tượng đã xoá",
    "Could not restore calendar or event" : "Không thể khôi phục lịch hoặc sự kiện",
    "Do you really want to empty the trash bin?" : "Bạn có chắc là muốn dọn sạch thùng rác hay không?",
    "No errors" : "Không có lỗi",
    "Open your browser console for more details" : "Mở trong trình duyệt để biết thêm chi tiết",
    "Due date" : "Thời hạn",
    "Last modified" : "Lần cuối chỉnh sửa",
    "[Yesterday]" : "[Hôm qua]",
    "[Today]" : "[Hôm nay]",
    "[Tomorrow]" : "[Ngày mai]",
    "Cancel" : "Hủy",
    "Close" : "Đóng",
    "Tomorrow" : "Ngày mai",
    "Add List…" : "Thêm vào danh sách…",
    "New List" : "Danh sách mới",
    "All day" : "Cả ngày",
    "Edit title" : "Chỉnh sửa tiêu đề",
    "Details" : "Chi tiết",
    "Select tags" : "Chọn một thẻ",
    "Notes" : "Ghi chú",
    "Reminders" : "Nhắc nhở",
    "Repeat" : "Lặp lại",
    "When shared show full event" : "Khi được chia sẻ thì thể hiện đầy đủ sự kiện",
    "When shared show only busy" : "Khi được chia sẻ thì chỉ thể hiện đang bận",
    "When shared hide this event" : "Khi được chia sẻ thì ẩn sự kiện này đi",
    "Canceled" : "Đã bị hủy",
    "An error occurred" : "Có lỗi đã xảy ra"
},
"nplurals=1; plural=0;");
